# unitorch.cli.models.clip

## ClipProcessor

!!! tip
    **`core/process/clip`** is the section for configuration of ClipProcessor.

::: unitorch.cli.models.clip.ClipProcessor

## ClipForPretrain

!!! tip
    **`core/model/pretrain/clip`** is the section for configuration of ClipForPretrain.

::: unitorch.cli.models.clip.ClipForPretrain

## ClipForClassification

!!! tip
    **`core/model/classification/clip`** is the section for configuration of ClipForClassification.

::: unitorch.cli.models.clip.ClipForClassification

## ClipForTextClassification

!!! tip
    **`core/model/classification/clip/text`** is the section for configuration of ClipForTextClassification.

::: unitorch.cli.models.clip.ClipForTextClassification

## ClipForImageClassification

!!! tip
    **`core/model/classification/clip/image`** is the section for configuration of ClipForImageClassification.

::: unitorch.cli.models.clip.ClipForImageClassification
